@@ -1,6 +1,7 @@
 import click
 
 from ..decorators import require_login
+from ..helpers.config import Config
 from ..helpers.params import get_profiles
 from .sym import sym
 
@@ -9,5 +10,7 @@ from .sym import sym
 @require_login
 def resources() -> None:
     """List resource groups available for use"""
+    default = Config.instance().get("default_resource")
     for (slug, profile) in get_profiles().items():
-        click.echo(f"{slug} ({profile.display_name})")
+        star = "* " if default == slug else ""
+        click.echo(f"{star}{slug} ({profile.display_name})")
