@@ -34,4 +34,15 @@ class InstanceNotFound(CliError):
 
 class FailedSubprocessError(CliError):
     def __init__(self, command) -> None:
-        super().__init__(f"Cannot run: {command}")
+        super().__init__(f"Cannot run {command}")
+
+
+class WrappedSubprocessError(CliError):
+    def __init__(self, wrapped, hint) -> None:
+        messages = [
+            f"Cannot run {wrapped.cmd[0]} [{wrapped.returncode}]",
+            f"Hint: {hint}",
+            f"\nThe original error was:",
+            wrapped.stderr,
+        ]
+        super().__init__("\n".join(messages))
