@@ -47,11 +47,15 @@ def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: "SymConfigFi
 def find_instance(saml_client, keys, value) -> Optional[str]:
     ec2_client = boto_client(saml_client, "ec2")
     for key in keys:
-        response = ec2_client.describe_instances(
-            Filters=[{"Name": key, "Values": [value]}], MaxResults=5
-        )
-        if response["Reservations"]:
-            return response["Reservations"][0]["Instances"][0]["InstanceId"]
+        paginator = ec2_client.get_paginator("describe_instances")
+        for response in paginator.paginate(
+            Filters=[
+                {"Name": "instance-state-name", "Values": ["running"]},
+                {"Name": key, "Values": [value]},
+            ],
+        ):
+            if response["Reservations"]:
+                return response["Reservations"][0]["Instances"][0]["InstanceId"]
 
 
 def host_to_instance(saml_client, host: str) -> str:
