@@ -5,6 +5,7 @@ from textwrap import dedent
 from typing import Sequence
 
 from ..decorators import intercept_errors, run_subprocess
+from ..errors import WrappedSubprocessError
 from ..helpers.boto import send_ssh_key
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
@@ -47,7 +48,6 @@ def _start_ssh_session(client: "SAMLClient", instance: str, port: int, *command:
     yield (*ssh_args(client, instance, port), *command)
 
 
-@intercept_errors(suppress=True)
 def start_ssh_session(
     client: "SAMLClient", instance: str, port: int, command: Sequence[str] = []
 ):
@@ -57,7 +57,9 @@ def start_ssh_session(
     except CalledProcessError as err:
         if MissingPublicKeyPattern.search(err.stderr):
             Config.touch_instance(instance, error=True)
-        raise
+        raise WrappedSubprocessError(
+            err, f"Does the user ({get_ssh_user()}) exist on the instance?"
+        ) from err
     else:
         Config.touch_instance(instance)
 
